pub struct Cblc<'a> {
data: FontData<'a>,
}Expand description
The Color Bitmap Location table
Fields
data: FontData<'a>Implementations
Sourceimpl<'a> Cblc<'a>
impl<'a> Cblc<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn major_version(&self) -> u16
pub fn major_version(&self) -> u16
Major version of the CBLC table, = 3.
Sourcepub fn minor_version(&self) -> u16
pub fn minor_version(&self) -> u16
Minor version of CBLC table, = 0.
Sourcepub fn bitmap_sizes(&self) -> &'a [BitmapSize]
pub fn bitmap_sizes(&self) -> &'a [BitmapSize]
BitmapSize records array.
pub fn major_version_byte_range(&self) -> Range<usize> ⓘ
pub fn minor_version_byte_range(&self) -> Range<usize> ⓘ
pub fn num_sizes_byte_range(&self) -> Range<usize> ⓘ
pub fn bitmap_sizes_byte_range(&self) -> Range<usize> ⓘ